@@ -23,9 +23,9 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE."""
 
 __all__ = ['bugreport', 'utils', 'urlutils', 'checkbuildd', 'checkversions',
-           'debianbts', 'exceptions', 'submit', 'tempfile']
+           'debbugs', 'exceptions', 'submit', 'tempfile']
 
-VERSION_NUMBER = "5.1.1ubuntu1"
+VERSION_NUMBER = "6.3.1ubuntu1"
 
 VERSION = "reportbug "+VERSION_NUMBER
 COPYRIGHT = VERSION + '\nCopyright (C) 1999-2008 Chris Lawrence <lawrencc@debian.org>' + \
