@@ -18,10 +18,6 @@
 ##  WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 ##  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 ##  SOFTWARE.
-#
-# Version ##VERSION##; see changelog for revision history
-#
-# $Id: reportbug_submit.py,v 1.20.2.6 2007-04-19 21:21:31 lawrencc Exp $
 
 import sys
 import os
@@ -42,7 +38,6 @@ from email.Header import Header
 import mimetypes
 
 from __init__ import VERSION, VERSION_NUMBER
-import debianbts
 from tempfiles import TempFile, open_write_safe, tempfile_prefix
 from exceptions import (
     NoMessage,
@@ -226,7 +221,8 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
                 rtype='debbugs', exinfo=None, replyto=None, printonly=False,
                 template=False, outfile=None, mta='', kudos=False,
                 smtptls=False, smtphost='localhost',
-                smtpuser=None, smtppasswd=None, paranoid=False, draftpath=None):
+                smtpuser=None, smtppasswd=None, paranoid=False, draftpath=None,
+                envelopefrom=None):
     '''Send a report.'''
 
     failed = using_sendmail = False
@@ -316,7 +312,7 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
         pipe = sys.stdout
     elif mua:
         pipe, filename = TempFile(prefix=tfprefix, dir=draftpath)
-    elif outfile or not mta or not os.path.exists(mta):
+    elif outfile or not ((mta and os.path.exists(mta)) or smtphost):
         msgname = outfile or ('/var/tmp/%s.bug' % package)
         if os.path.exists(msgname):
             try:
@@ -327,12 +323,14 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
         try:
             pipe = open_write_safe(msgname, 'w')
         except OSError:
+            # we can't write to the selected file, use a temp file instead
             fh, newmsgname = TempFile(prefix=tfprefix, dir=draftpath)
-            fh.write(message.as_string())
-            fh.close()
             ewrite('Writing to %s failed; '
-                   'wrote bug report to %s\n', msgname, newmsgname)
+                   'using instead %s\n', msgname, newmsgname)
             msgname = newmsgname
+            # we just need a place where to write() and a file handler
+            # is here just for that
+            pipe = fh
     elif mta and not smtphost:
         try:
             x = os.getcwd()
@@ -343,9 +341,13 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
         jalist = ' '.join(malist)
 
         faddr = rfc822.parseaddr(fromaddr)[1]
+        if envelopefrom:
+            envfrom = rfc822.parseaddr(envelopefrom)[1]
+        else:
+            envfrom = faddr
         ewrite("Sending message via %s...\n", mta)
         pipe = os.popen('%s -f %s -oi -oem %s' % (
-            mta, commands.mkarg(faddr), jalist), 'w')
+                mta, commands.mkarg(envfrom), jalist), 'w')
         using_sendmail = True
 
     if smtphost:
@@ -432,7 +434,8 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
             fh, msgname = TempFile(prefix=tfprefix, dir=draftpath)
             fh.write(message)
             fh.close()
-            ewrite('Original write failed, wrote bug report to %s\n', msgname)
+            ui.long_message('Error: send/write operation failed, bug report '
+                            'saved to %s\n', msgname)
 
     if mua:
         ewrite("Spawning %s...\n", mua.name)
@@ -452,7 +455,7 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
                     fh, msgname = TempFile(prefix=tfprefix, dir=draftpath)
                     fh.write(message)
                     fh.close()
-                    ewrite('Original write failed, wrote bug report to %s\n', msgname)
+                    ewrite('Draft saved into %s\n', msgname)
                     succeeded = True
             else:
                 succeeded = True
@@ -500,16 +503,3 @@ within an hour; if you haven't received a confirmation, then the bug reporting p
         # Message is misleading if an MUA is used.
         ewrite("A copy of the report is stored as: %s\n" % filename)
     return
-
-def main():
-    'o'
-
-if __name__ == '__main__':
-    try:
-        main()
-    except KeyboardInterrupt:
-        ewrite("\nreportbug: exiting due to user interrupt.\n")
-    except debianbts.Error, x:
-        ewrite('error accessing BTS: %s\n' % x)
-
-# vim:ts=8:sw=4:expandtab
