@@ -20,8 +20,6 @@
 ##  WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 ##  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 ##  SOFTWARE.
-#
-# Version ##VERSION##; see changelog for revision history
 
 import httplib
 import urllib
@@ -79,8 +77,8 @@ class HttpWithGzipHandler (urllib2.HTTPHandler):
 if hasattr(httplib, 'HTTPS'):
     class HttpsWithGzipHandler (urllib2.HTTPSHandler):
         "support gzip encoding"
-        def http_open (self, req):
-            return decode(urllib2.HTTPSHandler.http_open(self, req))
+        def https_open (self, req):
+            return decode(urllib2.HTTPSHandler.https_open(self, req))
 
 class handlepasswd(urllib2.HTTPPasswordMgrWithDefaultRealm):
     def find_user_password(self, realm, authurl):
@@ -182,8 +180,3 @@ def launch_browser(url):
         cmd = "%s %s" % (CONSOLEBROWSER, commands.mkarg(url))
 
     os.system(cmd)
-
-if __name__ == '__main__':
-    page = open_url('http://bugs.debian.org/reportbug')
-    content = page.read()
-    print page.info().headers
