@@ -19,10 +19,6 @@
 ##  WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 ##  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 ##  SOFTWARE.
-#
-# Version ##VERSION##; see changelog for revision history
-#
-# $Id: reportbug.py,v 1.35.2.24 2008-04-18 05:38:28 lawrencc Exp $
 
 import sys
 import os
@@ -30,7 +26,7 @@ import re
 import platform
 try:
     import pwd
-    from tempfiles import TempFile, tempfile_prefix
+    from tempfiles import TempFile, tempfile_prefix, cleanup_temp_file
 except ImportError, e:
     if platform.system() == 'Windows':
         pass
@@ -71,17 +67,33 @@ for mode in MODELIST:
 del mode
 
 # moved here since it needs the MODE_* vars to be defined
-import debianbts
-# it needs to be imported after debianbts
+import debbugs
+# it needs to be imported after debbugs
 import ui.text_ui as ui
 
 from reportbug.ui import AVAILABLE_UIS
 
-NEWBIELINE = '*** Please type your report below this line ***'
+NEWBIELINE = """Dear Maintainer,
+*** Please consider answering these questions, where appropriate ***
+
+   * What led up to the situation?
+   * What exactly did you do (or not do) that was effective (or
+     ineffective)?
+   * What was the outcome of this action?
+   * What outcome did you expect instead?
+
+*** End of the template - remove these lines ***"""
 
 fhs_directories = ['/', '/usr', '/usr/share', '/var', '/usr/X11R6',
                    '/usr/man', '/usr/doc', '/usr/bin']
 
+# A map between suites and distributions names
+SUITES2DISTS = {'lenny': 'oldstable',
+                'squeeze': 'stable',
+                'wheezy': 'testing',
+                'sid': 'unstable',
+                'experimental': 'experimental'}
+
 def realpath(filename):
     filename = os.path.abspath(filename)
 
@@ -398,12 +410,12 @@ def get_package_status(package, avail=False):
 
     reportinfo = None
     if bugs:
-        reportinfo = debianbts.parse_bts_url(bugs)
+        reportinfo = debbugs.parse_bts_url(bugs)
     elif origin:
-        if debianbts.SYSTEMS.has_key(origin):
-            vendor = debianbts.SYSTEMS[origin]['name']
-            reportinfo = (debianbts.SYSTEMS[origin].get('type', 'debbugs'),
-                          debianbts.SYSTEMS[origin]['btsroot'])
+        if debbugs.SYSTEMS.has_key(origin):
+            vendor = debbugs.SYSTEMS[origin]['name']
+            reportinfo = (debbugs.SYSTEMS[origin].get('type', 'debbugs'),
+                          debbugs.SYSTEMS[origin]['btsroot'])
         else:
             vendor = origin.capitalize()
     else:
@@ -634,16 +646,32 @@ def get_dependency_info(package, depends, rel="depends on"):
 
     deplist = packs.values()
     deplist.sort()
-    maxlen = max([len(x[2]) for x in deplist] + [10])
 
+    deplist2 = []
+    # extract the info we need, also add provides where it fits
     for (pack, status, vers, desc, provides) in deplist:
         if provides:
             pack += ' [' + provides + ']'
+        deplist2.append((pack, vers))
+    deplist = deplist2
 
-        packstuff = '%-*.*s %s' % (39-maxlen, 39-maxlen, pack, vers)
+    # now we can compute the max possible value for each column, that can be the
+    # max of all its values, or the space left from the other column; this way,
+    # the sum of the 2 fields is never > 73 (hence the resulting line is <80
+    # columns)
+    maxp = max([len(x[0]) for x in deplist])
+    maxv = max([len(x[1]) for x in deplist])
+    widthp = min(maxp, 73-maxv)
+    widthv = min(maxv, 73-widthp)
 
-        info = '%-3.3s %-40.40s %-.34s\n' % (status, packstuff, desc)
-        depinfo += info
+    for (pack, vers) in deplist:
+        # we format the string specifying to align it in a field of a given
+        # dimension (the first {width*}) but also limit its size (the second
+        # {width*}
+        info = '{0:3.3} {1:{widthp}.{widthp}}  {2:{widthv}.{widthv}}'.format(
+            status, pack, vers, widthp=widthp, widthv=widthv)
+        # remove tailing white spaces
+        depinfo += info.rstrip() + '\n'
 
     return depinfo
 
@@ -674,14 +702,14 @@ def get_changed_config_files(conffiles, nocompress=False):
 
     return confinfo, changed
 
-DISTORDER = ['stable', 'testing', 'unstable', 'experimental']
+DISTORDER = ['oldstable', 'stable', 'testing', 'unstable', 'experimental']
 
 def get_debian_release_info():
     debvers = debinfo = verfile = warn = ''
     dists = []
     output = commands.getoutput('apt-cache policy 2>/dev/null')
     if output:
-        mre = re.compile('\s+(\d+)\s+.*$\s+release\s.*o=(Ubuntu|Debian),a=([^,]+),', re.MULTILINE)
+        mre = re.compile('\s+(\d+)\s+.*$\s+release\s.*o=(Ubuntu|Debian|Debian Ports),a=([^,]+),', re.MULTILINE)
         found = {}
         ## XXX: When Python 2.4 rolls around, rewrite this
         for match in mre.finditer(output):
@@ -736,7 +764,7 @@ def get_arch():
 
 def generate_blank_report(package, pkgversion, severity, justification,
                           depinfo, confinfo, foundfile='', incfiles='',
-                          system='debian', exinfo=0, type=None, klass='',
+                          system='debian', exinfo=None, type=None, klass='',
                           subject='', tags='', body='', mode=MODE_EXPERT,
                           pseudos=None, debsumsoutput=None, issource=False):
     # For now...
@@ -776,7 +804,7 @@ def get_cpu_cores():
 class our_lex(shlex.shlex):
     def get_token(self):
         token = shlex.shlex.get_token(self)
-        if not len(token): return token
+        if token is None or not len(token): return token
         if (token[0] == token[-1]) and token[0] in self.quotes:
             token = token[1:-1]
         return token
@@ -828,6 +856,7 @@ MUA = {
     'mutt' : Mua('mutt -H'),
     'mh' : Mua('/usr/bin/mh/comp -use -file'),
     'gnus' : Gnus(),
+    'claws-mail' : Mua('claws-mail --compose-read'),
     }
 MUA['nmh'] = MUA['mh']
 
@@ -836,6 +865,7 @@ MUAVERSION = {
     MUA['mutt'] : 'mutt -v',
     MUA['mh'] : '/usr/bin/mh/comp -use -file',
     MUA['gnus'] : 'emacs --version',
+    MUA['claws-mail'] : 'claws-mail --version',
     }
 
 def mua_is_supported(mua):
@@ -896,19 +926,20 @@ def parse_config_files():
     for filename in FILES:
         if os.path.exists(filename):
             try:
-                lex = our_lex(file(filename))
+                lex = our_lex(file(filename), posix=True)
             except IOError, msg:
                 continue
 
             lex.wordchars = lex.wordchars + '-.@/:<>'
 
-            token = lex.get_token().lower()
+            token = lex.get_token()
             while token:
+                token = token.lower()
                 if token in ('quiet', 'maintonly', 'submit'):
                     args['sendto'] = token
                 elif token == 'severity':
                     token = lex.get_token().lower()
-                    if token in debianbts.SEVERITIES.keys():
+                    if token in debbugs.SEVERITIES.keys():
                         args['severity'] = token
                 elif token == 'header':
                     args['headers'] = args.get('headers', []) + \
@@ -949,7 +980,7 @@ def parse_config_files():
                         args[token] = arg
                 elif token == 'bts':
                     token = lex.get_token().lower()
-                    if token in debianbts.SYSTEMS.keys():
+                    if token in debbugs.SYSTEMS.keys():
                         args['bts'] = token
                 elif token == 'mirror':
                     args['mirrors'] = args.get('mirrors', []) + \
@@ -975,10 +1006,13 @@ def parse_config_files():
                 elif token == 'max_attachment_size':
                     arg = lex.get_token()
                     args['max_attachment_size'] = int(arg)
+                elif token == 'envelopefrom':
+                    token = lex.get_token().lower()
+                    args['envelopefrom'] = token
                 else:
                     sys.stderr.write('Unrecognized token: %s\n' % token)
 
-                token = lex.get_token().lower()
+                token = lex.get_token()
 
     return args
 
@@ -1114,3 +1148,53 @@ def launch_mbox_reader(cmd, url, http_proxy, timeout):
         os.system('mail -f ' + fname)
     finally:
         os.unlink(fname)
+
+def get_running_kernel_pkg():
+    """Return the package of the currently running kernel, needed to force
+    assignment for 'kernel' package to a real one"""
+
+    system = platform.system()
+    release = platform.release()
+
+    if system == 'Linux':
+        return 'linux-image-' + release
+    elif system == 'GNU/kFreeBSD':
+        return 'kfreebsd-image-' + release
+    else:
+        return None
+
+def exec_and_parse_bugscript(handler, bugscript):
+    """Execute and parse the output of the package bugscript, in particular
+    identifying the headers and pseudo-headers blocks, if present"""
+
+    fh, filename = TempFile()
+    fh.close()
+    rc = os.system('LC_ALL=C %s %s %s' % (handler, commands.mkarg(bugscript),
+                                          commands.mkarg(filename)))
+
+    isheaders = False
+    ispseudoheaders = False
+    headers = pseudoheaders = text = ''
+    fp = open(filename)
+    for line in fp.readlines():
+        # we identify the blocks for headers and pseudo-h
+        if line == '-- BEGIN HEADERS --\n':
+            isheaders = True
+        elif line == '-- END HEADERS --\n':
+            isheaders = False
+        elif line == '-- BEGIN PSEUDOHEADERS --\n':
+            ispseudoheaders = True
+        elif line == '-- END PSEUDOHEADERS --\n':
+            ispseudoheaders = False
+        else:
+            if isheaders:
+                headers += line
+            elif ispseudoheaders:
+                pseudoheaders += line
+            else:
+                text += line
+    fp.close()
+    cleanup_temp_file(filename)
+
+    text = text.decode('utf-8', 'replace')
+    return (rc, headers, pseudoheaders, text)
